# libyt frontend for yt

[![PyPI version](https://badge.fury.io/py/yt_libyt.svg)](https://badge.fury.io/py/yt_libyt)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/cindytsai/yt_libyt/main.svg)](https://results.pre-commit.ci/latest/github/cindytsai/yt_libyt/main)
[![Run Tests](https://github.com/cindytsai/yt_libyt/actions/workflows/build-test.yml/badge.svg)](https://github.com/cindytsai/yt_libyt/actions/workflows/build-test.yml)
[![Style Check](https://github.com/cindytsai/yt_libyt/actions/workflows/style-check.yml/badge.svg)](https://github.com/cindytsai/yt_libyt/actions/workflows/style-check.yml)


This is a [`yt`](https://yt-project.org/) frontend for [`libyt`](https://github.com/yt-project/libyt).


* **yt**: https://yt-project.org/
* **libyt Repo**: https://github.com/yt-project/libyt
* **libyt Doc**: https://yt-project.github.io/libyt/
